@@ -2,7 +2,12 @@ use strict;
 use warnings;
 package YAML::PP::Schema::Core;
 
-our $VERSION = '0.013_001'; # TRIAL VERSION
+our $VERSION = '0.014_001'; # TRIAL VERSION
+
+use YAML::PP::Schema::JSON qw/
+    represent_int represent_float represent_literal represent_bool
+    represent_undef
+/;
 
 use B;
 
@@ -65,89 +70,35 @@ sub register {
         match => [ all => sub { $_[1]->{value} } ],
     );
 
-    $schema->add_representer(
-        reftype => "*",
-        code => sub {
-            die "Dumping references not supported yet";
-        },
-    );
-
     my $int_flags = B::SVp_IOK;
     my $float_flags = B::SVp_NOK;
     $schema->add_representer(
         flags => $int_flags,
-        code => sub {
-            my ($rep, $node) = @_;
-            if (int($node->{value}) ne $node->{value}) {
-                return 0;
-            }
-            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-            $node->{data} = "$node->{value}";
-            return 1;
-        },
+        code => \&represent_int,
     );
-    my %special = ( (0+'nan').'' => '.nan', (0+'inf').'' => '.inf', (0-'inf').'' => '-.inf' );
     $schema->add_representer(
         flags => $float_flags,
-        code => sub {
-            my ($rep, $node) = @_;
-            if (exists $special{ $node->{value} }) {
-                $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-                $node->{data} = $special{ $node->{value} };
-                return 1;
-            }
-            if (0.0 + $node->{value} ne $node->{value}) {
-                return 0;
-            }
-            if (int($node->{value}) eq $node->{value} and not $node->{value} =~ m/\./) {
-                $node->{value} .= '.0';
-            }
-            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-            $node->{data} = "$node->{value}";
-            return 1;
-        },
+        code => \&represent_float,
     );
     $schema->add_representer(
-        undefined => sub {
-            my ($rep, $node) = @_;
-            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-            $node->{data} = 'null';
-            return 1;
-        },
+        undefined => \&represent_undef,
     );
     $schema->add_representer(
         equals => $_,
-        code => sub {
-            my ($rep, $node) = @_;
-            $node->{style} = YAML_QUOTED_SCALAR_STYLE;
-            $node->{data} = "$node->{value}";
-            return 1;
-        },
+        code => \&represent_literal,
     ) for ("", qw/
         true TRUE True false FALSE False null NULL Null ~
         .inf .Inf .INF -.inf -.Inf -.INF .nan .NaN .NAN
     /);
     $schema->add_representer(
         regex => qr{$RE_INT_CORE|$RE_FLOAT_CORE|$RE_INT_OCTAL|$RE_INT_HEX},
-        code => sub {
-            my ($rep, $node) = @_;
-            $node->{style} = YAML_QUOTED_SCALAR_STYLE;
-            $node->{data} = "$node->{value}";
-            return 1;
-        },
+        code => \&represent_literal,
     );
 
     if ($schema->bool_class) {
         $schema->add_representer(
             class_equals => $schema->bool_class,
-            code => sub {
-                my ($rep, $node) = @_;
-                my $string = $node->{value} ? 'true' : 'false';
-                $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-                @{ $node->{items} } = $string;
-                $node->{data} = $string;
-                return 1;
-            },
+            code => \&represent_bool,
         );
     }
 
