@@ -2,9 +2,12 @@ use strict;
 use warnings;
 package YAML::PP::Schema::YAML1_1;
 
-our $VERSION = '0.013_001'; # TRIAL VERSION
+our $VERSION = '0.014_001'; # TRIAL VERSION
 
-use base 'YAML::PP::Schema';
+use YAML::PP::Schema::JSON qw/
+    represent_int represent_float represent_literal represent_bool
+    represent_undef
+/;
 
 use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE YAML_QUOTED_SCALAR_STYLE /;
 
@@ -147,64 +150,22 @@ sub register {
         implicit => 0,
     );
 
-    $schema->add_representer(
-        reftype => "*",
-        code => sub {
-            die "Dumping references not supported yet";
-        },
-    );
-
     my $int_flags = B::SVp_IOK;
     my $float_flags = B::SVp_NOK;
     $schema->add_representer(
         flags => $int_flags,
-        code => sub {
-            my ($rep, $node) = @_;
-            if (int($node->{value}) ne $node->{value}) {
-                return 0;
-            }
-            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-            $node->{data} = "$node->{value}";
-            return 1;
-        },
+        code => \&represent_int,
     );
-    my %special = ( (0+'nan').'' => '.nan', (0+'inf').'' => '.inf', (0-'inf').'' => '-.inf' );
     $schema->add_representer(
         flags => $float_flags,
-        code => sub {
-            my ($rep, $node) = @_;
-            if (exists $special{ $node->{value} }) {
-                $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-                $node->{data} = $special{ $node->{value} };
-                return 1;
-            }
-            if (0.0 + $node->{value} ne $node->{value}) {
-                return 0;
-            }
-            if (int($node->{value}) eq $node->{value} and not $node->{value} =~ m/\./) {
-                $node->{value} .= '.0';
-            }
-            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-            $node->{data} = "$node->{value}";
-            return 1;
-        },
+        code => \&represent_float,
     );
     $schema->add_representer(
-        undefined => sub {
-            my ($rep, $node) = @_;
-            $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-            $node->{data} = 'null';
-            return 1;
-        },
+        undefined => \&represent_undef,
     );
     $schema->add_representer(
         equals => $_,
-        code => sub {
-            my ($rep, $node) = @_;
-            $node->{style} = YAML_QUOTED_SCALAR_STYLE;
-            $node->{data} = "$node->{value}";
-            return 1;
-        },
+        code => \&represent_literal,
     ) for ("", qw/
         true TRUE True y Y yes Yes YES on On ON
         false FALSE False n N n no No NO off Off OFF
@@ -213,25 +174,13 @@ sub register {
     /);
     $schema->add_representer(
         regex => qr{$RE_INT_1_1|$RE_FLOAT_1_1|$RE_INT_OCTAL_1_1|$RE_INT_HEX_1_1|$RE_INT_BIN_1_1|$RE_SEXAGESIMAL_INT|$RE_SEXAGESIMAL},
-        code => sub {
-            my ($rep, $node) = @_;
-            $node->{style} = YAML_QUOTED_SCALAR_STYLE;
-            $node->{data} = "$node->{value}";
-            return 1;
-        },
+        code => \&represent_literal,
     );
 
     if ($schema->bool_class) {
         $schema->add_representer(
             class_equals => $schema->bool_class,
-            code => sub {
-                my ($rep, $node) = @_;
-                my $string = $node->{value} ? 'true' : 'false';
-                $node->{style} = YAML_PLAIN_SCALAR_STYLE;
-                @{ $node->{items} } = $string;
-                $node->{data} = $string;
-                return 1;
-            },
+            code => \&represent_bool,
         );
     }
 
